@@ -20,7 +20,7 @@
 
 package org.videolan.libvlc.util;
 
-import android.os.Build;
+import android.net.Uri;
 
 import java.util.ArrayList;
 
@@ -29,7 +29,6 @@ import org.videolan.libvlc.LibVLC;
 import org.videolan.libvlc.Media;
 import org.videolan.libvlc.MediaDiscoverer;
 import org.videolan.libvlc.MediaList;
-import org.videolan.libvlc.VLCObject;
 
 public class MediaBrowser {
     private static final String TAG = "LibVLC/util/MediaBrowser";
@@ -41,12 +40,16 @@ public class MediaBrowser {
         //  "mdns"
     } : new String[]{"upnp"} ; //Only UPnP for release
 
-    private LibVLC mLibVlc;
-    private ArrayList<MediaDiscoverer> mMediaDiscoverers = new ArrayList<MediaDiscoverer>();
-    private ArrayList<Media> mDiscovererMediaArray = new ArrayList<Media>();
+    private final LibVLC mLibVlc;
+    private final ArrayList<MediaDiscoverer> mMediaDiscoverers = new ArrayList<MediaDiscoverer>();
+    private final ArrayList<Media> mDiscovererMediaArray = new ArrayList<Media>();
     private MediaList mBrowserMediaList;
     private Media mMedia;
     private EventListener mEventListener;
+    private boolean mAlive;
+
+    private static final String IGNORE_LIST_OPTION =  ":ignore-filetypes=";
+    private String mIgnoreList = "db,nfo,ini,jpg,jpeg,ljpg,gif,png,pgm,pgmyuv,pbm,pam,tga,bmp,pnm,xpm,xcf,pcx,tif,tiff,lbm,sfv,txt,sub,idx,srt,cue,ssa";
 
     /**
      * Listener called when medias are added or removed.
@@ -73,9 +76,10 @@ public class MediaBrowser {
     }
 
     public MediaBrowser(LibVLC libvlc, EventListener listener) {
-        mLibVlc = libvlc; // XXX mLibVlc.retain();
+        mLibVlc = libvlc;
+        mLibVlc.retain();
         mEventListener = listener;
-
+        mAlive = true;
     }
 
     private synchronized void reset() {
@@ -87,9 +91,11 @@ public class MediaBrowser {
             mMedia.release();
             mMedia = null;
         }
-        /* don't need to release the MediaList since it's either
-         * associated with a Media or a MediaDiscoverer that will release it */
-        mBrowserMediaList = null;
+
+        if (mBrowserMediaList != null) {
+            mBrowserMediaList.release();
+            mBrowserMediaList = null;
+        }
     }
 
     /**
@@ -97,6 +103,10 @@ public class MediaBrowser {
      */
     public synchronized void release() {
         reset();
+        if (!mAlive)
+            throw new IllegalStateException("MediaBrowser released more than one time");
+        mLibVlc.release();
+        mAlive = false;
     }
 
     /**
@@ -113,6 +123,7 @@ public class MediaBrowser {
         mMediaDiscoverers.add(md);
         final MediaList ml = md.getMediaList();
         ml.setEventListener(mDiscovererMediaListEventListener);
+        ml.release();
         md.start();
     }
 
@@ -135,12 +146,23 @@ public class MediaBrowser {
     }
 
     /**
-     * Browse to the specified mrl.
+     * Browse to the specified local path starting with '/'.
      *
-     * @param mrl
+     * @param path
      */
-    public synchronized void browse(String mrl) {
-        final Media media = new Media(mLibVlc, mrl);
+    public synchronized void browse(String path) {
+        final Media media = new Media(mLibVlc, path);
+        browse(media);
+        media.release();
+    }
+
+    /**
+     * Browse to the specified uri.
+     *
+     * @param uri
+     */
+    public synchronized void browse(Uri uri) {
+        final Media media = new Media(mLibVlc, uri);
         browse(media);
         media.release();
     }
@@ -155,6 +177,7 @@ public class MediaBrowser {
          * so increment ref count in order to don't clean it with the medialist
          */
         media.retain();
+        media.addOption(IGNORE_LIST_OPTION+mIgnoreList);
         reset();
         mBrowserMediaList = media.subItems();
         mBrowserMediaList.setEventListener(mBrowserMediaListEventListener);
@@ -170,17 +193,30 @@ public class MediaBrowser {
     }
 
     /**
-     * Get a media at a specified index.
+     * Get a media at a specified index. Should be released with {@link #release()}.
      */
     public synchronized Media getMediaAt(int index) {
-        return index >= 0 && index < getMediaCount() ?
-                mBrowserMediaList != null ? mBrowserMediaList.getMediaAt(index) :
-                mDiscovererMediaArray.get(index) : null;
+        if (index < 0 || index >= getMediaCount())
+            throw new IndexOutOfBoundsException();
+        final Media media = mBrowserMediaList != null ? mBrowserMediaList.getMediaAt(index) :
+                mDiscovererMediaArray.get(index);
+        media.retain();
+        return media;
     }
 
-    private MediaList.EventListener mBrowserMediaListEventListener = new MediaList.EventListener() {
+    /**
+     * Override the extensions list to be ignored in browsing
+     * default is "db,nfo,ini,jpg,jpeg,ljpg,gif,png,pgm,pgmyuv,pbm,pam,tga,bmp,pnm,xpm,xcf,pcx,tif,tiff,lbm,sfv,txt,sub,idx,srt,cue,ssa"
+     *
+     * @param list files extensions to be ignored by browser
+     */
+    public synchronized void setIgnoreFileTypes(String list) {
+        mIgnoreList = list;
+    }
+
+    private final MediaList.EventListener mBrowserMediaListEventListener = new MediaList.EventListener() {
         @Override
-        public void onEvent(VLCObject.Event event) {
+        public void onEvent(MediaList.Event event) {
             if (mEventListener == null)
                 return;
             final MediaList.Event mlEvent = (MediaList.Event) event;
@@ -189,21 +225,21 @@ public class MediaBrowser {
              * We use an intermediate array here since more than one MediaDiscoverer can be used
              */
             switch (mlEvent.type) {
-            case MediaList.Events.MediaListItemAdded:
+            case MediaList.Event.ItemAdded:
                 mEventListener.onMediaAdded(mlEvent.index, mlEvent.media);
                 break;
-            case MediaList.Events.MediaListItemDeleted:
+            case MediaList.Event.ItemDeleted:
                 mEventListener.onMediaRemoved(mlEvent.index, mlEvent.media);
                 break;
-            case MediaList.Events.MediaListEndReached:
+            case MediaList.Event.EndReached:
                 mEventListener.onBrowseEnd();
             }
         }
     };
 
-    private MediaList.EventListener mDiscovererMediaListEventListener = new MediaList.EventListener() {
+    private final MediaList.EventListener mDiscovererMediaListEventListener = new MediaList.EventListener() {
         @Override
-        public void onEvent(VLCObject.Event event) {
+        public void onEvent(MediaList.Event event) {
             if (mEventListener == null)
                 return;
             final MediaList.Event mlEvent = (MediaList.Event) event;
@@ -213,12 +249,12 @@ public class MediaBrowser {
              * We use an intermediate array here since more than one MediaDiscoverer can be used
              */
             switch (mlEvent.type) {
-            case MediaList.Events.MediaListItemAdded:
+            case MediaList.Event.ItemAdded:
                 synchronized (MediaBrowser.this) {
                     /* one item can be found by severals discoverers */
                     boolean found = false;
                     for (Media media : mDiscovererMediaArray) {
-                        if (media.getMrl().equals(mlEvent.media.getMrl())) {
+                        if (media.getUri().equals(mlEvent.media.getUri())) {
                             found = true;
                             break;
                         }
@@ -231,7 +267,7 @@ public class MediaBrowser {
                 if (index != -1)
                     mEventListener.onMediaAdded(index, mlEvent.media);
                 break;
-            case MediaList.Events.MediaListItemDeleted:
+            case MediaList.Event.ItemDeleted:
                 synchronized (MediaBrowser.this) {
                     index = mDiscovererMediaArray.indexOf(mlEvent.media);
                     if (index != -1)
@@ -240,7 +276,7 @@ public class MediaBrowser {
                 if (index != -1)
                     mEventListener.onMediaRemoved(index, mlEvent.media);
                 break;
-            case MediaList.Events.MediaListEndReached:
+            case MediaList.Event.EndReached:
                 mEventListener.onBrowseEnd();
             }
         }
