@@ -26,7 +26,6 @@ import java.text.SimpleDateFormat;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Date;
-import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Locale;
@@ -42,6 +41,7 @@ import android.graphics.Bitmap;
 import android.graphics.BitmapFactory;
 import android.net.Uri;
 import android.support.annotation.Nullable;
+import android.support.v4.util.ArrayMap;
 import android.util.Log;
 
 import org.videolan.libvlc.util.AndroidUtil;
@@ -53,7 +53,7 @@ public class MediaDatabase {
 
     private SQLiteDatabase mDb;
     private static final String DB_NAME = "vlc_database";
-    private static final int DB_VERSION = 21;
+    private static final int DB_VERSION = 22;
     private static final int CHUNK_SIZE = 50;
 
     private static final String DIR_TABLE_NAME = "directories_table";
@@ -102,12 +102,25 @@ public class MediaDatabase {
     private static final String NETWORK_FAV_URI = "uri";
     private static final String NETWORK_FAV_TITLE = "title";
 
-    public enum mediaColumn {
-        MEDIA_TABLE_NAME, MEDIA_PATH, MEDIA_TIME, MEDIA_LENGTH,
-        MEDIA_TYPE, MEDIA_PICTURE, MEDIA_TITLE, MEDIA_ARTIST, MEDIA_GENRE, MEDIA_ALBUM,
-        MEDIA_ALBUMARTIST, MEDIA_WIDTH, MEDIA_HEIGHT, MEDIA_ARTWORKURL, MEDIA_AUDIOTRACK,
-        MEDIA_SPUTRACK, MEDIA_TRACKNUMBER, MEDIA_DISCNUMBER, MEDIA_LAST_MODIFIED
-    }
+//    public static final int INDEX_MEDIA_TABLE_NAME = 0;
+//    public static final int INDEX_MEDIA_PATH = 1;
+    public static final int INDEX_MEDIA_TIME = 2;
+    public static final int INDEX_MEDIA_LENGTH = 3;
+//    public static final int INDEX_MEDIA_TYPE = 4;
+    public static final int INDEX_MEDIA_PICTURE = 5;
+//    public static final int INDEX_MEDIA_TITLE = 6;
+//    public static final int INDEX_MEDIA_ARTIST = 7;
+//    public static final int INDEX_MEDIA_GENRE = 8;
+//    public static final int INDEX_MEDIA_ALBUM = 9;
+//    public static final int INDEX_MEDIA_ALBUMARTIST = 10;
+//    public static final int INDEX_MEDIA_WIDTH = 11;
+//    public static final int INDEX_MEDIA_HEIGHT = 12;
+//    public static final int INDEX_MEDIA_ARTWORKURL = 13;
+    public static final int INDEX_MEDIA_AUDIOTRACK = 14;
+    public static final int INDEX_MEDIA_SPUTRACK = 15;
+//    public static final int INDEX_MEDIA_TRACKNUMBER = 16;
+//    public static final int INDEX_MEDIA_DISCNUMBER = 17;
+//    public static final int INDEX_MEDIA_LAST_MODIFIED = 18;
 
     /**
      * Constructor
@@ -292,59 +305,63 @@ public class MediaDatabase {
                     + DIR_ROW_PATH + " TEXT PRIMARY KEY NOT NULL"
                     + ");";
 
-            // Create the directories table
-            db.execSQL(createDirTabelQuery);
+            synchronized (this) {
+                // Create the directories table
+                db.execSQL(createDirTabelQuery);
 
-            // Create the media table
-            createMediaTableQuery(db);
+                // Create the media table
+                createMediaTableQuery(db);
 
-            // Create playlist tables
-            createPlaylistTablesQuery(db);
+                // Create playlist tables
+                createPlaylistTablesQuery(db);
 
-            String createSearchhistoryTabelQuery = "CREATE TABLE IF NOT EXISTS "
-                    + SEARCHHISTORY_TABLE_NAME + " ("
-                    + SEARCHHISTORY_KEY + " VARCHAR(200) PRIMARY KEY NOT NULL, "
-                    + SEARCHHISTORY_DATE + " DATETIME NOT NULL"
-                    + ");";
+                String createSearchhistoryTabelQuery = "CREATE TABLE IF NOT EXISTS "
+                        + SEARCHHISTORY_TABLE_NAME + " ("
+                        + SEARCHHISTORY_KEY + " VARCHAR(200) PRIMARY KEY NOT NULL, "
+                        + SEARCHHISTORY_DATE + " DATETIME NOT NULL"
+                        + ");";
 
-            // Create the searchhistory table
-            db.execSQL(createSearchhistoryTabelQuery);
+                // Create the searchhistory table
+                db.execSQL(createSearchhistoryTabelQuery);
 
-            createMRLTableQuery(db);
+                createMRLTableQuery(db);
 
-            createNetworkFavTableQuery(db);
+                createNetworkFavTableQuery(db);
+            }
         }
 
         @Override
         public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
-            dropMediaTableQuery(db);
-            createMediaTableQuery(db);
+            synchronized (this) {
+                dropMediaTableQuery(db);
+                createMediaTableQuery(db);
 
-            // Upgrade incrementally from oldVersion to newVersion
-            for(int i = oldVersion+1; i <= newVersion; i++) {
-                switch(i) {
-                case 9:
-                    // Remodelled playlist tables: re-create them
-                    db.execSQL("DROP TABLE " + PLAYLIST_MEDIA_TABLE_NAME + ";");
-                    db.execSQL("DROP TABLE " + PLAYLIST_TABLE_NAME + ";");
-                    createPlaylistTablesQuery(db);
-                    break;
-                case 11:
-                    createMRLTableQuery(db);
-                    break;
-                case 13:
-                    createNetworkFavTableQuery(db);
-                    break;
-                case 17:
-                    dropMRLTableQuery(db);
-                    createMRLTableQuery(db);
-                    break;
-                case 18:
-                    dropNetworkFavTableQuery(db);
-                    createNetworkFavTableQuery(db);
-                    break;
-                default:
-                    break;
+                // Upgrade incrementally from oldVersion to newVersion
+                for(int i = oldVersion+1; i <= newVersion; i++) {
+                    switch(i) {
+                    case 9:
+                        // Remodelled playlist tables: re-create them
+                        db.execSQL("DROP TABLE " + PLAYLIST_MEDIA_TABLE_NAME + ";");
+                        db.execSQL("DROP TABLE " + PLAYLIST_TABLE_NAME + ";");
+                        createPlaylistTablesQuery(db);
+                        break;
+                    case 11:
+                        createMRLTableQuery(db);
+                        break;
+                    case 13:
+                        createNetworkFavTableQuery(db);
+                        break;
+                    case 17:
+                        dropMRLTableQuery(db);
+                        createMRLTableQuery(db);
+                        break;
+                    case 18:
+                        dropNetworkFavTableQuery(db);
+                        createNetworkFavTableQuery(db);
+                        break;
+                    default:
+                        break;
+                    }
                 }
             }
         }
@@ -355,7 +372,7 @@ public class MediaDatabase {
      *
      * @return An array of all the playlist names
      */
-    public String[] getPlaylists() {
+    public synchronized String[] getPlaylists() {
         ArrayList<String> playlists = new ArrayList<String>();
         Cursor c = mDb.query(
                 PLAYLIST_TABLE_NAME,
@@ -376,7 +393,7 @@ public class MediaDatabase {
      * @param name Unique name of the playlist
      * @return False if invalid name or already exists, true otherwise
      */
-    public boolean playlistAdd(String name) {
+    public synchronized boolean playlistAdd(String name) {
         // Check length
         if(name.length() >= 200)
             return false;
@@ -397,7 +414,7 @@ public class MediaDatabase {
      *
      * @param name Unique name of the playlist
      */
-    public void playlistDelete(String name) {
+    public synchronized void playlistDelete(String name) {
         mDb.delete(PLAYLIST_TABLE_NAME, PLAYLIST_NAME + "=?",
                 new String[]{ name });
         mDb.delete(PLAYLIST_MEDIA_TABLE_NAME, PLAYLIST_MEDIA_PLAYLISTNAME
@@ -410,7 +427,7 @@ public class MediaDatabase {
      * @param name Unique name of the playlist
      * @return true if playlist exists, false otherwise
      */
-    public boolean playlistExists(String name) {
+    public synchronized boolean playlistExists(String name) {
         // Check duplicates
         Cursor c = mDb.query(PLAYLIST_TABLE_NAME,
                 new String[] { PLAYLIST_NAME }, PLAYLIST_NAME + "= ?",
@@ -430,7 +447,7 @@ public class MediaDatabase {
      * @return Array containing MRLs of the playlist in order, or null on error
      */
    @Nullable
-    public String[] playlistGetItems(String playlistName) {
+    public synchronized String[] playlistGetItems(String playlistName) {
         if(!playlistExists(playlistName))
             return null;
 
@@ -462,7 +479,7 @@ public class MediaDatabase {
      * @param position Position to insert into
      * @param mrl MRL of the media
      */
-    public void playlistInsertItem(String playlistName, int position, String mrl) {
+    public synchronized void playlistInsertItem(String playlistName, int position, String mrl) {
         playlistShiftItems(playlistName, position, 1);
 
         ContentValues values = new ContentValues();
@@ -492,7 +509,7 @@ public class MediaDatabase {
      * @param position Position to start shifting at
      * @param factor Factor to shift the order by
      */
-    private void playlistShiftItems(String playlistName, int position, int factor) {
+    private synchronized void playlistShiftItems(String playlistName, int position, int factor) {
         // Increment all media orders by 1 after the insert position
         Cursor c = mDb.query(
                 PLAYLIST_MEDIA_TABLE_NAME,
@@ -520,7 +537,7 @@ public class MediaDatabase {
      * @param playlistName Unique name of the playlist
      * @param position Position to remove
      */
-    public void playlistRemoveItem(String playlistName, int position) {
+    public synchronized void playlistRemoveItem(String playlistName, int position) {
         mDb.delete(PLAYLIST_MEDIA_TABLE_NAME,
                 PLAYLIST_MEDIA_PLAYLISTNAME + "=? AND " +
                 PLAYLIST_MEDIA_ORDER + "=?",
@@ -537,7 +554,7 @@ public class MediaDatabase {
      * @return false on error, if playlist doesn't exist or if the new name
      * already exists, true otherwise
      */
-    public boolean playlistRename(String playlistName, String newPlaylistName) {
+    public synchronized boolean playlistRename(String playlistName, String newPlaylistName) {
         if(!playlistExists(playlistName) || playlistExists(newPlaylistName))
             return false;
 
@@ -667,10 +684,10 @@ public class MediaDatabase {
         return mediaList;
     }
 
-    public synchronized HashMap<String, MediaWrapper> getMedias() {
+    public synchronized ArrayMap<String, MediaWrapper> getMedias() {
 
         Cursor cursor;
-        HashMap<String, MediaWrapper> medias = new HashMap<String, MediaWrapper>();
+        ArrayMap<String, MediaWrapper> medias = new ArrayMap<String, MediaWrapper>();
         int chunk_count = 0;
         int count;
 
@@ -738,10 +755,10 @@ public class MediaDatabase {
         return medias;
     }
 
-    public synchronized HashMap<String, Long> getVideoTimes() {
+    public synchronized ArrayMap<String, Long> getVideoTimes() {
 
         Cursor cursor;
-        HashMap<String, Long> times = new HashMap<String, Long>();
+        ArrayMap<String, Long> times = new ArrayMap<String, Long>();
         int chunk_count = 0;
         int count;
 
@@ -868,7 +885,7 @@ public class MediaDatabase {
         mDb.delete(MEDIA_TABLE_NAME, MEDIA_LOCATION + "=?", new String[]{uri.toString()});
     }
 
-    public void removeMedias(Collection<Uri> uris) {
+    public synchronized void removeMedias(Collection<Uri> uris) {
         mDb.beginTransaction();
         try {
             for (Uri uri : uris)
@@ -879,7 +896,7 @@ public class MediaDatabase {
         }
     }
 
-    public void removeMediaWrappers(Collection<MediaWrapper> mws) {
+    public synchronized void removeMediaWrappers(Collection<MediaWrapper> mws) {
         mDb.beginTransaction();
         try {
             for (MediaWrapper mw : mws)
@@ -890,7 +907,7 @@ public class MediaDatabase {
         }
     }
 
-    public synchronized void updateMedia(Uri uri, mediaColumn col,
+    public synchronized void updateMedia(Uri uri, int col,
             Object object) {
 
         if (uri == null)
@@ -898,7 +915,7 @@ public class MediaDatabase {
 
         ContentValues values = new ContentValues();
         switch (col) {
-            case MEDIA_PICTURE:
+            case INDEX_MEDIA_PICTURE:
                 if (object != null) {
                     Bitmap picture = (Bitmap) object;
                     ByteArrayOutputStream out = new ByteArrayOutputStream();
@@ -909,19 +926,19 @@ public class MediaDatabase {
                     values.put(MEDIA_PICTURE, new byte[1]);
                 }
                 break;
-            case MEDIA_TIME:
+            case INDEX_MEDIA_TIME:
                 if (object != null)
                     values.put(MEDIA_TIME, (Long)object);
                 break;
-            case MEDIA_AUDIOTRACK:
+            case INDEX_MEDIA_AUDIOTRACK:
                 if (object != null)
                     values.put(MEDIA_AUDIOTRACK, (Integer)object);
                 break;
-            case MEDIA_SPUTRACK:
+            case INDEX_MEDIA_SPUTRACK:
                 if (object != null)
                     values.put(MEDIA_SPUTRACK, (Integer)object);
                 break;
-            case MEDIA_LENGTH:
+            case INDEX_MEDIA_LENGTH:
                 if (object != null)
                     values.put(MEDIA_LENGTH, (Long)object);
                 break;
@@ -1138,7 +1155,7 @@ public class MediaDatabase {
         try {
             getInstance().updateMedia(
                 m.getUri(),
-                    mediaColumn.MEDIA_PICTURE,
+                    INDEX_MEDIA_PICTURE,
                 p);
         } catch (SQLiteFullException e) {
             Log.d(TAG, "SQLiteFullException while setting picture");
