@@ -65,7 +65,6 @@ import org.videolan.libvlc.MediaList;
 import org.videolan.libvlc.MediaPlayer;
 import org.videolan.libvlc.util.AndroidUtil;
 import org.videolan.vlc.gui.AudioPlayerContainerActivity;
-import org.videolan.vlc.gui.MainActivity;
 import org.videolan.vlc.gui.audio.AudioUtil;
 import org.videolan.vlc.gui.video.VideoPlayerActivity;
 import org.videolan.vlc.util.Util;
@@ -124,6 +123,8 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
     private final IBinder mBinder = new LocalBinder();
     private MediaWrapperList mMediaList = new MediaWrapperList();
     private MediaPlayer mMediaPlayer;
+    private boolean mSeekable = false;
+    private boolean mPausable = false;
     private boolean mIsAudioTrack = false;
     private boolean mHasHdmiAudio = false;
 
@@ -681,6 +682,12 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
                     break;
                 case MediaPlayer.Event.ESDeleted:
                     break;
+                case MediaPlayer.Event.PausableChanged:
+                    mPausable = event.getPausable();
+                    break;
+                case MediaPlayer.Event.SeekableChanged:
+                    mSeekable = event.getSeekable();
+                    break;
             }
             for (Callback callback : mCallbacks)
                 callback.onMediaPlayerEvent(event);
@@ -966,11 +973,13 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
 
     @MainThread
     public void pause() {
-        savePosition();
-        mHandler.removeMessages(SHOW_PROGRESS);
-        // hideNotification(); <-- see event handler
-        mMediaPlayer.pause();
-        broadcastMetadata();
+        if (mPausable) {
+            savePosition();
+            mHandler.removeMessages(SHOW_PROGRESS);
+            // hideNotification(); <-- see event handler
+            mMediaPlayer.pause();
+            broadcastMetadata();
+        }
     }
 
     @MainThread
@@ -1135,19 +1144,18 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
     @MainThread
     public void next() {
         int size = mMediaList.size();
-        if (size > 1) {
-            mPrevious.push(mCurrentIndex);
-            mCurrentIndex = mNextIndex;
-            Log.d(TAG, "setting current to "+mCurrentIndex);
-            if (size == 0 || mCurrentIndex < 0 || mCurrentIndex >= size) {
-                if (mCurrentIndex < 0)
-                    saveCurrentMedia();
-                Log.w(TAG, "Warning: invalid next index, aborted !");
-                stop();
-                return;
-            }
-        } else
-            setPosition(0f);
+
+        mPrevious.push(mCurrentIndex);
+        mCurrentIndex = mNextIndex;
+        Log.d(TAG, "setting current to " + mCurrentIndex);
+        if (size == 0 || mCurrentIndex < 0 || mCurrentIndex >= size) {
+            if (mCurrentIndex < 0)
+                saveCurrentMedia();
+            Log.w(TAG, "Warning: invalid next index, aborted !");
+            stop();
+            return;
+        }
+
         playIndex(mCurrentIndex, 0);
         onMediaChanged();
     }
@@ -1342,6 +1350,16 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
         return mMediaPlayer.isPlaying();
     }
 
+    @MainThread
+    public boolean isSeekable() {
+        return mSeekable;
+    }
+
+    @MainThread
+    public boolean isPausable() {
+        return mPausable;
+    }
+
     @MainThread
     public boolean isShuffling() {
         return mShuffling;
@@ -1698,7 +1716,8 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
 
     @MainThread
     public void setTime(long time) {
-        mMediaPlayer.setTime(time);
+        if (mSeekable)
+            mMediaPlayer.setTime(time);
     }
 
     @MainThread
@@ -1773,7 +1792,8 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
 
     @MainThread
     public void setPosition(float pos) {
-        mMediaPlayer.setPosition(pos);
+        if (mSeekable)
+            mMediaPlayer.setPosition(pos);
     }
 
     @MainThread
