@@ -23,11 +23,12 @@
 package org.videolan.vlc.gui.browser;
 
 import android.annotation.TargetApi;
+import android.content.Intent;
+import android.net.Uri;
 import android.os.Build;
 import android.os.Bundle;
 import android.os.Message;
 import android.support.v4.app.Fragment;
-import android.support.v4.app.FragmentManager;
 import android.support.v4.app.FragmentTransaction;
 import android.support.v7.app.AlertDialog;
 import android.support.v7.widget.LinearLayoutManager;
@@ -44,19 +45,16 @@ import android.view.View;
 import android.view.ViewGroup;
 import android.widget.TextView;
 
-import org.videolan.libvlc.LibVLC;
-import org.videolan.libvlc.LibVlcUtil;
 import org.videolan.libvlc.Media;
+import org.videolan.libvlc.util.AndroidUtil;
 import org.videolan.libvlc.util.MediaBrowser;
-import org.videolan.vlc.MediaLibrary;
 import org.videolan.vlc.MediaWrapper;
 import org.videolan.vlc.R;
 import org.videolan.vlc.VLCApplication;
-import org.videolan.vlc.audio.AudioServiceController;
-import org.videolan.vlc.gui.CommonDialogs;
 import org.videolan.vlc.gui.DividerItemDecoration;
 import org.videolan.vlc.gui.MainActivity;
-import org.videolan.vlc.gui.SidebarAdapter;
+import org.videolan.vlc.gui.SecondaryActivity;
+import org.videolan.vlc.gui.dialogs.CommonDialogs;
 import org.videolan.vlc.gui.video.VideoPlayerActivity;
 import org.videolan.vlc.interfaces.IRefreshable;
 import org.videolan.vlc.util.Util;
@@ -88,7 +86,6 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
     protected MediaWrapper mCurrentMedia;
     protected int mSavedPosition = -1, mFavorites = 0;
     public boolean mRoot;
-    protected LibVLC mLibVLC;
 
     private SparseArray<ArrayList<MediaWrapper>> mMediaLists = new SparseArray<ArrayList<MediaWrapper>>();
     private ArrayList<MediaWrapper> mediaList;
@@ -105,8 +102,6 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
 
     public void onCreate(Bundle bundle){
         super.onCreate(bundle);
-        mLibVLC = VLCInstance.get();
-        mMediaBrowser = new MediaBrowser(mLibVLC, this);
 
         if (bundle == null)
             bundle = getArguments();
@@ -120,15 +115,22 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
             else
                 mMrl = bundle.getString(KEY_MRL);
             mSavedPosition = bundle.getInt(KEY_POSITION);
+        } else if (getActivity().getIntent() != null){
+            mMrl = getActivity().getIntent().getDataString();
+            getActivity().setIntent(null);
         }
     }
 
+    protected int getLayoutId(){
+        return R.layout.directory_browser;
+    }
+
     public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState){
-        View v = inflater.inflate(R.layout.directory_browser, container, false);
+        View v = inflater.inflate(getLayoutId(), container, false);
         mRecyclerView = (ContextMenuRecyclerView) v.findViewById(R.id.network_list);
         mEmptyView = (TextView) v.findViewById(android.R.id.empty);
         mLayoutManager = new LinearLayoutManager(getActivity());
-        mRecyclerView.addItemDecoration(new DividerItemDecoration(getActivity(), DividerItemDecoration.VERTICAL_LIST));
+        mRecyclerView.addItemDecoration(new DividerItemDecoration(VLCApplication.getAppContext(), DividerItemDecoration.VERTICAL_LIST));
         mRecyclerView.setLayoutManager(mLayoutManager);
         mRecyclerView.setAdapter(mAdapter);
         mRecyclerView.addOnScrollListener(mScrollListener);
@@ -140,10 +142,22 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
         return v;
     }
 
+    @Override
+    public void onStart() {
+        super.onStart();
+        mMediaBrowser = new MediaBrowser(VLCInstance.get(), this);
+    }
+
     public void onStop(){
         super.onStop();
-        if (mMediaBrowser != null)
+        releaseBrowser();
+    }
+
+    private void releaseBrowser() {
+        if (mMediaBrowser != null) {
             mMediaBrowser.release();
+            mMediaBrowser = null;
+        }
     }
 
     public void onSaveInstanceState(Bundle outState){
@@ -184,7 +198,7 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
             getActivity().finish();
     }
 
-    public void browse (MediaWrapper media, int position){
+    public void browse (MediaWrapper media, int position, boolean save){
         FragmentTransaction ft = getActivity().getSupportFragmentManager().beginTransaction();
         Fragment next = createFragment();
         Bundle args = new Bundle();
@@ -194,7 +208,8 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
         args.putParcelable(KEY_MEDIA, media);
         next.setArguments(args);
         ft.replace(R.id.fragment_placeholder, next, media.getLocation());
-        ft.addToBackStack(mMrl);
+        if (save)
+            ft.addToBackStack(mMrl);
         ft.commit();
     }
 
@@ -214,7 +229,7 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
 
     @Override
     public void onBrowseEnd() {
-        mMediaBrowser.release();
+        releaseBrowser();
         mHandler.sendEmptyMessage(BrowserFragmentHandler.MSG_HIDE_LOADING);
         if (mReadyToDisplay)
             display();
@@ -245,7 +260,6 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
      */
     protected void updateEmptyView(){
         if (mAdapter.isEmpty()){
-            mEmptyView.setText(getString(R.string.directory_empty));
             mEmptyView.setVisibility(View.VISIBLE);
             mRecyclerView.setVisibility(View.GONE);
             mSwipeRefreshLayout.setEnabled(false);
@@ -257,9 +271,13 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
     }
 
     protected void update(){
+        update(false);
+    }
+
+    protected void update(boolean force){
         if (mReadyToDisplay) {
             updateEmptyView();
-            if (mAdapter.isEmpty()) {
+            if (force || mAdapter.isEmpty()) {
                 refresh();
             } else {
                 updateDisplay();
@@ -282,12 +300,15 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
     @Override
     public void refresh() {
         mAdapter.clear();
-        mMediaBrowser.changeEventListener(this);
+        if (mMediaBrowser == null)
+            mMediaBrowser = new MediaBrowser(VLCInstance.get(), this);
+        else
+            mMediaBrowser.changeEventListener(this);
         mCurrentParsedPosition = 0;
         if (mRoot)
             browseRoot();
         else
-            mMediaBrowser.browse(mMrl);
+            mMediaBrowser.browse(mCurrentMedia != null ? mCurrentMedia.getUri() : Uri.parse(mMrl));
         mHandler.sendEmptyMessageDelayed(BrowserFragmentHandler.MSG_SHOW_LOADING, 300);
     }
 
@@ -316,10 +337,10 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
     }
 
     protected void focusHelper() {
-        if (getActivity() == null)
+        if (getActivity() == null || !(getActivity() instanceof MainActivity))
             return;
         boolean isEmpty = mAdapter.isEmpty();
-        MainActivity main = (MainActivity)getActivity();
+        MainActivity main = (MainActivity) getActivity();
         main.setMenuFocusDown(isEmpty, R.id.network_list);
         main.setSearchAsFocusDown(isEmpty, getView(), R.id.network_list);
     }
@@ -339,9 +360,12 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
     protected void setContextMenu(MenuInflater inflater, Menu menu, int position) {
         MediaWrapper mw = (MediaWrapper) mAdapter.getItem(position);
         boolean canWrite = Util.canWrite(mw.getLocation());
-        if (mw.getType() == MediaWrapper.TYPE_AUDIO || mw.getType() == MediaWrapper.TYPE_VIDEO) {
+        boolean isAudio = mw.getType() == MediaWrapper.TYPE_AUDIO;
+        boolean isVideo = mw.getType() == MediaWrapper.TYPE_VIDEO;
+        if (isAudio || isVideo) {
             inflater.inflate(R.menu.directory_view_file, menu);
             menu.findItem(R.id.directory_view_delete).setVisible(canWrite);
+            menu.findItem(R.id.directory_view_info).setVisible(isVideo);
         } else if (mw.getType() == MediaWrapper.TYPE_DIR) {
             boolean isEmpty = mMediaLists.get(position) == null || mMediaLists.get(position).isEmpty();
             if (canWrite || !isEmpty) {
@@ -371,7 +395,7 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
 
     @TargetApi(Build.VERSION_CODES.HONEYCOMB)
     public void onPopupMenu(View anchor, final int position) {
-        if (!LibVlcUtil.isHoneycombOrLater()) {
+        if (!AndroidUtil.isHoneycombOrLater()) {
             // Call the "classic" context menu
             anchor.performLongClick();
             return;
@@ -395,11 +419,14 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
         MediaWrapper mw = (MediaWrapper) mAdapter.getItem(position);
         switch (id){
             case R.id.directory_view_play:
-                Util.openMedia(getActivity(), (MediaWrapper) mAdapter.getItem(position));
+                mw.removeFlags(MediaWrapper.MEDIA_FORCE_AUDIO);
+                Util.openMedia(getActivity(), mw);
                 return true;
-            case R.id.directory_view_append:
-                AudioServiceController.getInstance().append(mw);
+            case R.id.directory_view_append: {
+                if (mService != null)
+                    mService.append(mw);
                 return true;
+            }
             case R.id.directory_view_delete:
                 AlertDialog alertDialog = CommonDialogs.deleteMedia(
                         mw.getType(), getActivity(), mw.getLocation(),
@@ -411,11 +438,21 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
                         });
                 alertDialog.show();
                 return true;
-            case R.id.directory_view_play_audio:
-                AudioServiceController.getInstance().load(mw);
+            case  R.id.directory_view_info:
+                Intent i = new Intent(getActivity(), SecondaryActivity.class);
+                i.putExtra("fragment", "mediaInfo");
+                i.putExtra("param", mw.getUri().toString());
+                startActivity(i);
                 return true;
+            case R.id.directory_view_play_audio: {
+                if (mService != null) {
+                    mw.addFlags(MediaWrapper.MEDIA_FORCE_AUDIO);
+                    mService.load(mw);
+                }
+                return true;
+            }
             case  R.id.directory_view_play_video:
-                VideoPlayerActivity.start(getActivity(), mw.getLocation());
+                VideoPlayerActivity.start(getActivity(), mw.getUri());
                 return true;
             case R.id.directory_view_play_folder:
                 ArrayList<MediaWrapper> mediaList = new ArrayList<MediaWrapper>();
@@ -439,36 +476,21 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
         return false;
     }
 
-    protected void updateLib() {
-        FragmentManager fm = getFragmentManager();
-        FragmentTransaction ft = fm.beginTransaction();
-        Fragment fragment = fm.findFragmentByTag(SidebarAdapter.SidebarEntry.ID_AUDIO);
-        if (fragment != null) {
-            ft.remove(fragment);
-            ((MediaBrowserFragment)fragment).clear();
-        }
-        fragment = fm.findFragmentByTag(SidebarAdapter.SidebarEntry.ID_VIDEO);
-        if (fragment != null) {
-            ft.remove(fragment);
-            ((MediaBrowserFragment)fragment).clear();
-        }
-        if (!ft.isEmpty())
-            ft.commit();
-        MediaLibrary.getInstance().loadMediaItems();
-    }
-
     protected void parseSubDirectories() {
         if (mCurrentParsedPosition == -1 || mAdapter.isEmpty())
             return;
         mMediaLists.clear();
-        mMediaBrowser.changeEventListener(mFoldersBrowserListener);
+        if (mMediaBrowser == null)
+            mMediaBrowser = new MediaBrowser(VLCInstance.get(), mFoldersBrowserListener);
+        else
+            mMediaBrowser.changeEventListener(mFoldersBrowserListener);
         mCurrentParsedPosition = 0;
         Object item;
         MediaWrapper mw;
         while (mCurrentParsedPosition <mAdapter.getItemCount()){
             item = mAdapter.getItem(mCurrentParsedPosition);
             if (item instanceof BaseBrowserAdapter.Storage) {
-                mw = new MediaWrapper(((BaseBrowserAdapter.Storage) item).getPath());
+                mw = new MediaWrapper(((BaseBrowserAdapter.Storage) item).getUri());
                 mw.setType(MediaWrapper.TYPE_DIR);
             } else  if (item instanceof MediaWrapper){
                 mw = (MediaWrapper) item;
@@ -476,7 +498,7 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
                 mw = null;
             if (mw != null){
                 if (mw.getType() == MediaWrapper.TYPE_DIR || mw.getType() == MediaWrapper.TYPE_PLAYLIST){
-                    mMediaBrowser.browse(mw.getLocation());
+                    mMediaBrowser.browse(mw.getUri());
                     return;
                 }
             }
@@ -504,7 +526,7 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
         public void onBrowseEnd() {
             if (mAdapter.isEmpty()) {
                 mCurrentParsedPosition = -1;
-                mMediaBrowser.release();
+                releaseBrowser();
                 return;
             }
             String holderText = getDescription(directories.size(), files.size());
@@ -521,7 +543,7 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
                     if (mw.getType() == MediaWrapper.TYPE_DIR || mw.getType() == MediaWrapper.TYPE_PLAYLIST)
                         break;
                 } else if (mAdapter.getItem(mCurrentParsedPosition) instanceof BaseBrowserAdapter.Storage) {
-                    mw = new MediaWrapper(((BaseBrowserAdapter.Storage) mAdapter.getItem(mCurrentParsedPosition)).getPath());
+                    mw = new MediaWrapper(((BaseBrowserAdapter.Storage) mAdapter.getItem(mCurrentParsedPosition)).getUri());
                     break;
                 } else
                     mw = null;
@@ -529,12 +551,13 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
 
             if (mw != null) {
                 if (mCurrentParsedPosition < mAdapter.getItemCount()) {
-                    mMediaBrowser.browse(mw.getLocation());
+                    mMediaBrowser.browse(mw.getUri());
                 } else {
                     mCurrentParsedPosition = -1;
-                    mMediaBrowser.release();
+                    releaseBrowser();
                 }
-            }
+            } else
+                releaseBrowser();
             directories .clear();
             files.clear();
         }
