@@ -1,8 +1,10 @@
 package org.videolan.vlc.gui.video;
 
 import android.os.Message;
+import android.util.Log;
 
 import org.videolan.vlc.MediaLibrary;
+import org.videolan.vlc.MediaWrapper;
 import org.videolan.vlc.interfaces.IVideoBrowser;
 import org.videolan.vlc.util.WeakHandler;
 
@@ -21,9 +23,10 @@ public class VideoListHandler extends WeakHandler<IVideoBrowser> {
 
         switch (msg.what) {
             case UPDATE_ITEM:
-                owner.updateItem();
+                owner.updateItem((MediaWrapper)msg.obj);
                 break;
             case MediaLibrary.MEDIA_ITEMS_UPDATED:
+                Log.d("load", "MEDIA_ITEMS_UPDATED");
                 owner.updateList();
                 break;
         }
