@@ -25,10 +25,7 @@ import java.util.concurrent.BrokenBarrierException;
 import org.videolan.vlc.MediaWrapper;
 
 public interface IVideoBrowser extends IBrowser {
-
-    public void resetBarrier();
     public void setItemToUpdate(MediaWrapper item);
-    public void await() throws InterruptedException, BrokenBarrierException;
-    public void updateItem();
+    public void updateItem(MediaWrapper item);
     public void updateList();
 }
