@@ -29,7 +29,6 @@ import android.content.Context;
 import android.content.Intent;
 import android.graphics.Bitmap;
 import android.os.Build;
-import android.view.View;
 import android.widget.RemoteViews;
 
 import org.videolan.libvlc.util.AndroidUtil;
@@ -38,9 +37,8 @@ import org.videolan.vlc.R;
 import org.videolan.vlc.VLCApplication;
 import org.videolan.vlc.gui.MainActivity;
 
-public class VLCAppWidgetProvider extends AppWidgetProvider {
+abstract public class VLCAppWidgetProvider extends AppWidgetProvider {
     public static final String TAG = "VLC/VLCAppWidgetProvider";
-    public static final String START_FROM_NOTIFICATION = "from_notification";
     public static final String ACTION_REMOTE_BACKWARD = "org.videolan.vlc.remote.Backward";
     public static final String ACTION_REMOTE_PLAYPAUSE = "org.videolan.vlc.remote.PlayPause";
     public static final String ACTION_REMOTE_STOP = "org.videolan.vlc.remote.Stop";
@@ -76,7 +74,7 @@ public class VLCAppWidgetProvider extends AppWidgetProvider {
             return;
         }
 
-        RemoteViews views = new RemoteViews(BuildConfig.APPLICATION_ID, R.layout.vlcwidget);
+        RemoteViews views = new RemoteViews(BuildConfig.APPLICATION_ID, getLayout());
         boolean partial = AndroidUtil.isHoneycombOrLater();
 
         if (ACTION_WIDGET_INIT.equals(action) || !partial) {
@@ -86,7 +84,6 @@ public class VLCAppWidgetProvider extends AppWidgetProvider {
             Intent iStop = new Intent(ACTION_REMOTE_STOP);
             Intent iForward = new Intent(ACTION_REMOTE_FORWARD);
             Intent iVlc = new Intent(VLCApplication.getAppContext(), MainActivity.class);
-            iVlc.putExtra(START_FROM_NOTIFICATION, true);
 
             PendingIntent piBackward = PendingIntent.getBroadcast(context, 0, iBackward, PendingIntent.FLAG_UPDATE_CURRENT);
             PendingIntent piPlay = PendingIntent.getBroadcast(context, 0, iPlay, PendingIntent.FLAG_UPDATE_CURRENT);
@@ -109,8 +106,7 @@ public class VLCAppWidgetProvider extends AppWidgetProvider {
 
             views.setTextViewText(R.id.songName, title);
             views.setTextViewText(R.id.artist, artist);
-            views.setImageViewResource(R.id.play_pause, isplaying ? R.drawable.ic_widget_pause : R.drawable.ic_widget_play);
-            views.setViewVisibility(R.id.timeline_parent, artist != null && artist.length() > 0 ? View.VISIBLE : View.INVISIBLE);
+            views.setImageViewResource(R.id.play_pause, getPlayPauseImage(isplaying));
         }
         else if (ACTION_WIDGET_UPDATE_COVER.equals(action)) {
             Bitmap cover = intent.getParcelableExtra("cover");
@@ -125,11 +121,16 @@ public class VLCAppWidgetProvider extends AppWidgetProvider {
             views.setProgressBar(R.id.timeline, 100, (int) (100 * pos), false);
         }
 
-        ComponentName widget = new ComponentName(context, VLCAppWidgetProvider.class);
+        ComponentName widget = new ComponentName(context, this.getClass());
         AppWidgetManager manager = AppWidgetManager.getInstance(context);
         if (partial)
             manager.partiallyUpdateAppWidget(manager.getAppWidgetIds(widget), views);
         else
             manager.updateAppWidget(widget, views);
     }
+
+    abstract protected int getLayout();
+
+    abstract protected int getPlayPauseImage(boolean isPlaying);
+
 }
