@@ -30,8 +30,7 @@ import org.videolan.vlc.MediaWrapper;
 import org.videolan.vlc.PlaybackService;
 import org.videolan.vlc.R;
 import org.videolan.vlc.gui.DividerItemDecoration;
-import org.videolan.vlc.gui.PlaybackServiceActivity;
-import org.videolan.vlc.gui.PreferencesActivity;
+import org.videolan.vlc.gui.preferences.PreferencesActivity;
 import org.videolan.vlc.gui.audio.AudioUtil;
 import org.videolan.vlc.gui.audio.MediaComparators;
 import org.videolan.vlc.gui.tv.browser.BaseTvActivity;
