@@ -26,22 +26,23 @@ package org.videolan.vlc.gui.tv.browser;
 import android.os.AsyncTask;
 import android.os.Bundle;
 import android.os.Handler;
+import android.support.v4.util.SimpleArrayMap;
 
 import org.videolan.vlc.MediaWrapper;
 import org.videolan.vlc.R;
 import org.videolan.vlc.Thumbnailer;
 import org.videolan.vlc.gui.tv.MainTvActivity;
+import org.videolan.vlc.gui.tv.browser.interfaces.BrowserActivityInterface;
 import org.videolan.vlc.gui.video.VideoListHandler;
 import org.videolan.vlc.interfaces.IVideoBrowser;
 
 import java.util.ArrayList;
-import java.util.HashMap;
-import java.util.concurrent.BrokenBarrierException;
 
 public class VideoGridFragment extends MediaLibBrowserFragment implements IVideoBrowser {
 
     private Handler mHandler = new VideoListHandler(this);
     protected static Thumbnailer sThumbnailer;
+    SimpleArrayMap<String, Integer> mMediaIndex;
 
     private volatile AsyncVideoUpdate mUpdater = null;
 
@@ -53,7 +54,7 @@ public class VideoGridFragment extends MediaLibBrowserFragment implements IVideo
     public void onResume() {
         super.onResume();
         mMediaLibrary.addUpdateHandler(mHandler);
-        if (mAdapter.size() == 0 && mUpdater == null) {
+        if (mUpdater == null) {
             mUpdater = new AsyncVideoUpdate();
             mUpdater.execute();
         }
@@ -77,7 +78,7 @@ public class VideoGridFragment extends MediaLibBrowserFragment implements IVideo
         protected void onPreExecute(){
             setTitle(getString(R.string.app_name_full));
             mAdapter.clear();
-            ((BrowserActivity)getActivity()).showProgress(true);
+            ((BrowserActivityInterface)getActivity()).showProgress(true);
         }
         @Override
         protected Void doInBackground(Void... params) {
@@ -86,11 +87,11 @@ public class VideoGridFragment extends MediaLibBrowserFragment implements IVideo
 
             ArrayList<MediaWrapper> mediaList = mMediaLibrary.getVideoItems();
             size = mediaList == null ? 0 : mediaList.size();
-            mMediaIndex = new HashMap<String, Integer>(size);
+            mMediaIndex = new SimpleArrayMap<String, Integer>(size);
 
             for (int i = 0 ; i < size ; ++i){
                 MediaWrapper = mediaList.get(i);
-                mMediaIndex.put(MediaWrapper.getLocation(), i);
+                mMediaIndex.put(MediaWrapper.getLocation(), Integer.valueOf(i));
                 publishProgress(MediaWrapper);
             }
             return null;
@@ -102,25 +103,20 @@ public class VideoGridFragment extends MediaLibBrowserFragment implements IVideo
 
         @Override
         protected void onPostExecute(Void result) {
-            ((BrowserActivity)getActivity()).showProgress(false);
+            ((BrowserActivityInterface)getActivity()).showProgress(false);
             setOnItemViewClickedListener(mClickListener);
         }
     }
 
     @Override
     public void setItemToUpdate(MediaWrapper item) {
-        mItemToUpdate = item;
-        mHandler.sendEmptyMessage(VideoListHandler.UPDATE_ITEM);
+        mHandler.sendMessage(mHandler.obtainMessage(VideoListHandler.UPDATE_ITEM, item));
     }
 
-    public void updateItem() {
-        if (mAdapter != null && mMediaIndex != null && mItemToUpdate != null
-                && mMediaIndex.containsKey(mItemToUpdate.getLocation()))
-            mAdapter.notifyArrayItemRangeChanged(mMediaIndex.get(mItemToUpdate.getLocation()), 1);
-        try {
-            mBarrier.await();
-        } catch (InterruptedException e) {
-        } catch (BrokenBarrierException e) {}
+    public void updateItem(MediaWrapper item) {
+        if (mAdapter != null && mMediaIndex != null && item != null
+                && mMediaIndex.containsKey(item.getLocation()))
+            mAdapter.notifyArrayItemRangeChanged(mMediaIndex.get(item.getLocation()).intValue(), 1);
     }
 
     @Override
@@ -141,12 +137,4 @@ public class VideoGridFragment extends MediaLibBrowserFragment implements IVideo
 
     @Override
     public void clearTextInfo() {}
-
-    public void await() throws InterruptedException, BrokenBarrierException {
-        mBarrier.await();
-    }
-
-    public void resetBarrier() {
-        mBarrier.reset();
-    }
 }
